@@ -15,7 +15,10 @@ pub enum TlError {
     #[error("Terminal error code: {0}")]
     TerminalError(i64),
     #[error("Nix error: {0}")]
+    #[cfg(unix)]
     NixError(#[from] nix::errno::Errno),
+    //#[error("Nix error: {0}")]
+    //NixError(i32),
     #[error("No $COLORFGBG env variable")]
     NoColorFgBgEnv,
     #[error("Var error: {0}")]
